# pyg-bond
The package contains simple bond price manipulation needed for Futures trading:

- conversion of australian bank bills quotes to prices (IR Comdty in Bloomberg)
- conversion of australian bond futures quotes to prices (XMA/YMA Comdty in Bloomberg)
- Simple derivation of price & duration from yield for bonds
- Newton Raphson yield & duration calculation from a given price using gradient descent

